#' taylor: Lyrics and song data for Taylor Swift's discography
#'
#' A comprehensive resource for data on Taylor Swift songs. Data for all
#' officially released studio albums, extended plays (EPs), and individual
#' singles are included. Data comes from <https://genius.com/> (lyrics) and
#' <https://www.spotify.com/us/> (song characteristics).
#'
#' @importFrom ggplot2 waiver
#'
#' @noRd
#' @name taylor
"_PACKAGE"

#' Internal vctrs methods
#'
#' @import vctrs
#' @keywords internal
#' @name taylor-vctrs
NULL

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @importFrom tibble tibble
#' @importFrom methods setOldClass
#' @importFrom lifecycle deprecated is_present deprecate_warn deprecate_soft
## usethis namespace: end
NULL
